
# RedHatCheck.py - originally based off of MandrakeCheck.py

from Filter import *
import AbstractCheck
import rpm
import re
import Config

class RedHatCheck(AbstractCheck.AbstractCheck):

    man_regex=re.compile("/man./")
    info_regex=re.compile("/info/")
    info_dir_regex=re.compile("/info/dir$")
    gz_regex=re.compile(".gz$")
    vendor=Config.getOption("Vendor", "Red Hat, Inc.")
    distribution=Config.getOption("Distribution", "BlueSky")
    
    def __init__(self):
	AbstractCheck.AbstractCheck.__init__(self, "RedHatCheck")

    def check(self, pkg, verbose):
	# Check only binary package
	if pkg.isSource():
	    return
	
	if pkg[rpm.RPMTAG_VENDOR] != RedHatCheck.vendor:
	    printWarning(pkg, "invalid-vendor", pkg[rpm.RPMTAG_VENDOR])

	if pkg[rpm.RPMTAG_DISTRIBUTION] != RedHatCheck.distribution:
	    printWarning(pkg, "invalid-distribution", pkg[rpm.RPMTAG_DISTRIBUTION])

	# Check the listing of files
	list=pkg[rpm.RPMTAG_FILENAMES]
	
	if list:
	    for f in list:
		if RedHatCheck.man_regex.search(f):
		    if not RedHatCheck.gz_regex.search(f):
			printWarning(pkg, "manpage-not-gzipped", f)
		if RedHatCheck.info_regex.search(f) and not RedHatCheck.info_dir_regex.search(f):
		    if not RedHatCheck.gz_regex.search(f):
			    printWarning(pkg, "infopage-not-gzipped", f)

# Create an object to enable the auto registration of the test
check=RedHatCheck()

